Anyioutils is a set of utility classes and functions that make working with [AnyIO](https://anyio.readthedocs.io) a little bit easier. In particular, developers coming from [asyncio](https://docs.python.org/3/library/asyncio.html) will find it more familiar. If AnyIO wants to bring [Trio](https://trio.readthedocs.io)'s semantics to asyncio, anyioutils wants to bring asyncio's semantics back to AnyIO. For instance, you will find the equivalent of a [Future](https://docs.python.org/3/library/asyncio-future.html) or a [Task](https://docs.python.org/3/library/asyncio-task.html#creating-tasks).
